@@ -30,7 +30,7 @@ int main(int argc, char *argv[])
     SmsSender a(argc, argv);
     a.setApplicationVersion(QUOTE(APP_VERSION));
 
-    qInstallMsgHandler(SimpleLoggingHandler); // to suppress d-bus warnings
+    qInstallMsgHandler(SimpleLoggingHandler);
 
     return a.exec();
 }
