@@ -42,6 +42,7 @@ private:
         argSend,
         argLog,
         argDontSave,
+        argFlash,
     };
 
     enum errors{
@@ -57,6 +58,7 @@ private:
     bool m_Compose;
     bool m_Send;
     bool m_Save;
+    bool m_Flash;
     QFile* m_LogFile;
 
     void consoleOutput(QString output, bool newline=true);
